==> vgkprogaming-0.4.3.tar.gz: lib/utils/convertors.dart <==
import 'dart:convert';
import 'package:vgkprogaming/model/vgk-about-us-model.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-model.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-sub-model.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-with-popup-model.dart';
import 'package:vgkprogaming/model/vgk-card-image-widget-model.dart';
import 'package:vgkprogaming/model/vgk-card-vertical-top-bottom-content-model.dart';
import 'package:vgkprogaming/model/vgk-drop-down-map-model.dart';
import 'package:vgkprogaming/model/vgk-map-details-model.dart';

class VgkConvertor {
  static List<VgkCardHorizontalModel> vgkCardHorizontalFromMap(String str) =>
      List<VgkCardHorizontalModel>.from(
        json.decode(str).map(
              (x) => VgkCardHorizontalModel.fromMap(x),
            ),
      );

  static List<VgkCardHorizontalSubModel> vgkCardHorizontalSubFromMap(
          String str) =>
      List<VgkCardHorizontalSubModel>.from(
        json.decode(str).map(
              (x) => VgkCardHorizontalSubModel.fromMap(x),
            ),
      );

  static List<VgkCardHorizontalWithPopupModel>
      vgkCardHorizontalWithPopupFromMap(String str) =>
          List<VgkCardHorizontalWithPopupModel>.from(
            json.decode(str).map(
                  (x) => VgkCardHorizontalWithPopupModel.fromMap(x),
                ),
          );

  static List<VgkCardVerticalTopBottomContentModel>
      vgkCardVerticalTopBottomContentFromMap(String str) =>
          List<VgkCardVerticalTopBottomContentModel>.from(
            json.decode(str).map(
                  (x) => VgkCardVerticalTopBottomContentModel.fromMap(x),
                ),
          );

  static List<VgkDropdownMapModel> vgkDropdownMapModelFromMap(String str) =>
      List<VgkDropdownMapModel>.from(
        json.decode(str).map(
              (x) => VgkDropdownMapModel.fromMap(x),
            ),
      );

  static List<VgkCardImageWidgetModel> vgkCardImageWidgetModelFromMap(
          String str) =>
      List<VgkCardImageWidgetModel>.from(
        json.decode(str).map(
              (x) => VgkCardImageWidgetModel.fromMap(x),
            ),
      );

  static List<VgkMapDetailsModel> vgkMapDetailsModelFromMap(String str) =>
      List<VgkMapDetailsModel>.from(
        json.decode(str).map(
              (x) => VgkMapDetailsModel.fromMap(x),
            ),
      );

  static List<VgkAboutUsModel> vgkAboutUsModelFromMap(String str) =>
      List<VgkAboutUsModel>.from(
          json.decode(str).map((x) => VgkAboutUsModel.fromMap(x)));
}

==> vgkprogaming-0.4.9.tar.gz: lib/utils/convertors.dart <==
import 'dart:convert';
import 'package:vgkprogaming/model/vgk-about-us-model.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-model.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-with-sub-model.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-with-popup-model.dart';
import 'package:vgkprogaming/model/vgk-card-image-widget-model.dart';
import 'package:vgkprogaming/model/vgk-card-vertical-top-bottom-content-model.dart';
import 'package:vgkprogaming/model/vgk-drop-down-map-model.dart';
import 'package:vgkprogaming/model/vgk-map-details-model.dart';

class VgkConvertor {
  static List<VgkCardHorizontalModel> vgkCardHorizontalFromMap(String str) =>
      List<VgkCardHorizontalModel>.from(
        json.decode(str).map(
              (x) => VgkCardHorizontalModel.fromMap(x),
            ),
      );

  static List<VgkCardHorizontalWithSubModel> vgkCardHorizontalWithSubFromMap(
          String str) =>
      List<VgkCardHorizontalWithSubModel>.from(
        json.decode(str).map(
              (x) => VgkCardHorizontalWithSubModel.fromMap(x),
            ),
      );

  static List<VgkCardHorizontalWithPopupModel>
      vgkCardHorizontalWithPopupFromMap(String str) =>
          List<VgkCardHorizontalWithPopupModel>.from(
            json.decode(str).map(
                  (x) => VgkCardHorizontalWithPopupModel.fromMap(x),
                ),
          );

  static List<VgkCardVerticalTopBottomContentModel>
      vgkCardVerticalTopBottomContentFromMap(String str) =>
          List<VgkCardVerticalTopBottomContentModel>.from(
            json.decode(str).map(
                  (x) => VgkCardVerticalTopBottomContentModel.fromMap(x),
                ),
          );

  static List<VgkDropdownMapModel> vgkDropdownMapModelFromMap(String str) =>
      List<VgkDropdownMapModel>.from(
        json.decode(str).map(
              (x) => VgkDropdownMapModel.fromMap(x),
            ),
      );

  static List<VgkCardImageWidgetModel> vgkCardImageWidgetModelFromMap(
          String str) =>
      List<VgkCardImageWidgetModel>.from(
        json.decode(str).map(
              (x) => VgkCardImageWidgetModel.fromMap(x),
            ),
      );

  static List<VgkMapDetailsModel> vgkMapDetailsModelFromMap(String str) =>
      List<VgkMapDetailsModel>.from(
        json.decode(str).map(
              (x) => VgkMapDetailsModel.fromMap(x),
            ),
      );

  static List<VgkAboutUsModel> vgkAboutUsModelFromMap(String str) =>
      List<VgkAboutUsModel>.from(
        json.decode(str).map(
              (x) => VgkAboutUsModel.fromMap(x),
            ),
      );
}
